##  Overview
SAP LeanIX AI capabilities use generative AI to make enterprise architecture data more accessible and actionable. They automate tedious documentation tasks, provide contextual insights, enable natural language queries, assist with text refinement and translation, and extract architectural elements from documents.
In LeanIX, AI capabilities are available through three main feature sets:
  * Base AI capabilities: Embedded assistance in the inventory and workspace UI, including inventory AI prompts, AI‑assisted text, AI‑generated context, and AI‑supported translation.
  * Inventory builder (premium AI feature): AI that analyzes diagrams and images to propose fact sheets and relations, helping you build and enrich your inventory faster.
  * Joule in SAP LeanIX: SAP’s generative AI assistant that lets you search LeanIX content and get answers to questions about LeanIX using natural language.
